@@ -19,7 +19,7 @@ from tencentcloud.common.abstract_model import AbstractModel
 
 
 class License(AbstractModel):
-    """表示应用实例的软件授权，包含颁发信息、激活信息等内容。
+    r"""表示应用实例的软件授权，包含颁发信息、激活信息等内容。
 
     """
 
@@ -85,7 +85,7 @@ class License(AbstractModel):
 
     @property
     def LicenseId(self):
-        """License ID
+        r"""License ID
         :rtype: str
         """
         return self._LicenseId
@@ -96,7 +96,7 @@ class License(AbstractModel):
 
     @property
     def LicenseMode(self):
-        """软件授权模式。<table><thead><tr><th>枚举值</th><th>说明</th></tr></thead><tbody><tr><td>Permanent</td><td>永久授权。该授权不受有效期限制。</td></tr><tr><td>Subscription</td><td>订阅授权。授权如果过了有效期，则会进入过期状态。</td></tr><tr><td>Accept</td><td>验收期授权。用于需要验收的软件处于验收期间的授权，授权如果过了验收有效期，则会进入过期状态。</td></tr></tbody></table>
+        r"""软件授权模式。<table><thead><tr><th>枚举值</th><th>说明</th></tr></thead><tbody><tr><td>Permanent</td><td>永久授权。该授权不受有效期限制。</td></tr><tr><td>Subscription</td><td>订阅授权。授权如果过了有效期，则会进入过期状态。</td></tr><tr><td>Accept</td><td>验收期授权。用于需要验收的软件处于验收期间的授权，授权如果过了验收有效期，则会进入过期状态。</td></tr></tbody></table>
         :rtype: str
         """
         return self._LicenseMode
@@ -107,7 +107,7 @@ class License(AbstractModel):
 
     @property
     def LicenseStatus(self):
-        """软件的授权状态。<table><thead><tr><th>枚举值</th><th>说明</th></tr></thead><tbody><tr><td>Issued</td><td>已颁发，等待激活。一般来说，如果软件已经在运行，不会出现该状态。</td></tr><tr><td>Active</td><td>授权在有效期内，这是软件运行期间最常见的状态。</td></tr><tr><td>Expired</td><td>授权已过期。订阅类的软件授权有有效期，如果服务器时间已晚于有效期，则会进入过期状态。</td></tr><tr><td>Isolated</td><td>授权已隔离。有截止日期的授权，当用户授权到期时，先进入此状态，用户可以去续费，超过7天不续费则授权进入Destroyed状态。</td></tr><tr><td>Destroyed</td><td>授权已失效/销毁。用户如果退货软件，则授权会自动失效。</td></tr></tbody></table>
+        r"""软件的授权状态。<table><thead><tr><th>枚举值</th><th>说明</th></tr></thead><tbody><tr><td>Issued</td><td>已颁发，等待激活。一般来说，如果软件已经在运行，不会出现该状态。</td></tr><tr><td>Active</td><td>授权在有效期内，这是软件运行期间最常见的状态。</td></tr><tr><td>Expired</td><td>授权已过期。订阅类的软件授权有有效期，如果服务器时间已晚于有效期，则会进入过期状态。</td></tr><tr><td>Isolated</td><td>授权已隔离。有截止日期的授权，当用户授权到期时，先进入此状态，用户可以去续费，超过7天不续费则授权进入Destroyed状态。</td></tr><tr><td>Destroyed</td><td>授权已失效/销毁。用户如果退货软件，则授权会自动失效。</td></tr></tbody></table>
         :rtype: str
         """
         return self._LicenseStatus
@@ -118,7 +118,7 @@ class License(AbstractModel):
 
     @property
     def ProviderId(self):
-        """软件供应方 ID。
+        r"""软件供应方 ID。
         :rtype: int
         """
         return self._ProviderId
@@ -129,7 +129,7 @@ class License(AbstractModel):
 
     @property
     def SoftwarePackageId(self):
-        """软件包 ID。
+        r"""软件包 ID。
         :rtype: str
         """
         return self._SoftwarePackageId
@@ -140,7 +140,7 @@ class License(AbstractModel):
 
     @property
     def SoftwarePackageVersion(self):
-        """软件包版本。
+        r"""软件包版本。
         :rtype: str
         """
         return self._SoftwarePackageVersion
@@ -151,7 +151,7 @@ class License(AbstractModel):
 
     @property
     def AuthorizedUserUin(self):
-        """被授权的用户 UIN。
+        r"""被授权的用户 UIN。
         :rtype: str
         """
         return self._AuthorizedUserUin
@@ -162,7 +162,7 @@ class License(AbstractModel):
 
     @property
     def AuthorizedCloudappId(self):
-        """被授权的应用实例 ID。
+        r"""被授权的应用实例 ID。
         :rtype: str
         """
         return self._AuthorizedCloudappId
@@ -173,7 +173,7 @@ class License(AbstractModel):
 
     @property
     def AuthorizedCloudappRoleId(self):
-        """被授权的角色 ID。
+        r"""被授权的角色 ID。
         :rtype: str
         """
         return self._AuthorizedCloudappRoleId
@@ -184,7 +184,7 @@ class License(AbstractModel):
 
     @property
     def AuthorizedSpecification(self):
-        """被授权的软件规格，具体字段请参考结构SaleParam
+        r"""被授权的软件规格，具体字段请参考结构SaleParam
         :rtype: list of SaleParam
         """
         return self._AuthorizedSpecification
@@ -195,7 +195,7 @@ class License(AbstractModel):
 
     @property
     def BillingMode(self):
-        """被授权的软件的计费模式。<table><thead><tr><th>枚举值</th><th>说明</th></tr></thead><tbody><tr><td>1</td><td>线上计费，软件的授权从腾讯云线上购买，支持续费、退款等操作。</td></tr><tr><td>2</td><td>线下计费，软件的授权线下签订合同购买，定向客户交付，无法从线上续费和退款。</td></tr><tr><td>4</td><td>免费</td></tr></tbody></table>
+        r"""被授权的软件的计费模式。<table><thead><tr><th>枚举值</th><th>说明</th></tr></thead><tbody><tr><td>1</td><td>线上计费，软件的授权从腾讯云线上购买，支持续费、退款等操作。</td></tr><tr><td>2</td><td>线下计费，软件的授权线下签订合同购买，定向客户交付，无法从线上续费和退款。</td></tr><tr><td>4</td><td>免费</td></tr></tbody></table>
         :rtype: int
         """
         return self._BillingMode
@@ -206,7 +206,7 @@ class License(AbstractModel):
 
     @property
     def LifeSpan(self):
-        """授权时长（单位由LifeSpanUnit确定，枚举值有Y年/M月/D日三种）
+        r"""授权时长（单位由LifeSpanUnit确定，枚举值有Y年/M月/D日三种）
         :rtype: int
         """
         return self._LifeSpan
@@ -217,7 +217,7 @@ class License(AbstractModel):
 
     @property
     def IssueDate(self):
-        """授权颁发时间。
+        r"""授权颁发时间。
         :rtype: str
         """
         return self._IssueDate
@@ -228,7 +228,7 @@ class License(AbstractModel):
 
     @property
     def ActivationDate(self):
-        """授权激活时间，如从未激活则返回 null。
+        r"""授权激活时间，如从未激活则返回 null。
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -240,7 +240,7 @@ class License(AbstractModel):
 
     @property
     def ExpirationDate(self):
-        """授权过期时间
+        r"""授权过期时间
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -252,7 +252,7 @@ class License(AbstractModel):
 
     @property
     def LifeSpanUnit(self):
-        """授权时长单位，枚举值有Y年/M月/D日三种
+        r"""授权时长单位，枚举值有Y年/M月/D日三种
         :rtype: str
         """
         return self._LifeSpanUnit
@@ -263,7 +263,7 @@ class License(AbstractModel):
 
     @property
     def LicenseType(self):
-        """授权的类型：Standard正式版/Development开发版/Trial体验版
+        r"""授权的类型：Standard正式版/Development开发版/Trial体验版
         :rtype: str
         """
         return self._LicenseType
@@ -274,7 +274,7 @@ class License(AbstractModel):
 
     @property
     def LicenseLevel(self):
-        """授权的层级：Master 主授权；Child 子授权/增强型授权
+        r"""授权的层级：Master 主授权；Child 子授权/增强型授权
         :rtype: str
         """
         return self._LicenseLevel
@@ -319,7 +319,7 @@ class License(AbstractModel):
 
 
 class SaleParam(AbstractModel):
-    """表示商品 SKU 的单个售卖参数
+    r"""表示商品 SKU 的单个售卖参数
 
     """
 
@@ -348,7 +348,7 @@ class SaleParam(AbstractModel):
 
     @property
     def ParamKey(self):
-        """售卖参数标识
+        r"""售卖参数标识
         :rtype: str
         """
         return self._ParamKey
@@ -359,7 +359,7 @@ class SaleParam(AbstractModel):
 
     @property
     def ParamKeyName(self):
-        """售卖参数的展示名称
+        r"""售卖参数的展示名称
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -371,7 +371,7 @@ class SaleParam(AbstractModel):
 
     @property
     def ParamValue(self):
-        """售卖参数值，当ParamType=Quant时，该值有可能为Null
+        r"""售卖参数值，当ParamType=Quant时，该值有可能为Null
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -383,7 +383,7 @@ class SaleParam(AbstractModel):
 
     @property
     def ParamValueName(self):
-        """售卖参数值的展示名称
+        r"""售卖参数值的展示名称
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -395,7 +395,7 @@ class SaleParam(AbstractModel):
 
     @property
     def ParamType(self):
-        """售卖参数的类型，目前支持枚举类Enum/数量类Quant
+        r"""售卖参数的类型，目前支持枚举类Enum/数量类Quant
 注意：此字段可能返回 null，表示取不到有效值。
         :rtype: str
         """
@@ -423,13 +423,13 @@ class SaleParam(AbstractModel):
 
 
 class VerifyLicenseRequest(AbstractModel):
-    """VerifyLicense请求参数结构体
+    r"""VerifyLicense请求参数结构体
 
     """
 
 
 class VerifyLicenseResponse(AbstractModel):
-    """VerifyLicense返回参数结构体
+    r"""VerifyLicense返回参数结构体
 
     """
 
@@ -451,7 +451,7 @@ class VerifyLicenseResponse(AbstractModel):
 
     @property
     def License(self):
-        """软件的详细授权信息。
+        r"""软件的详细授权信息。
         :rtype: :class:`tencentcloud.cloudapp.v20220530.models.License`
         """
         return self._License
@@ -462,7 +462,7 @@ class VerifyLicenseResponse(AbstractModel):
 
     @property
     def Timestamp(self):
-        """当前请求服务端的时间戳，格式为RFC3339
+        r"""当前请求服务端的时间戳，格式为RFC3339
         :rtype: str
         """
         return self._Timestamp
@@ -473,7 +473,7 @@ class VerifyLicenseResponse(AbstractModel):
 
     @property
     def Signature(self):
-        """对License字段对应的json数据的签名
+        r"""对License字段对应的json数据的签名
         :rtype: str
         """
         return self._Signature
@@ -484,7 +484,7 @@ class VerifyLicenseResponse(AbstractModel):
 
     @property
     def RequestId(self):
-        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        r"""唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :rtype: str
         """
         return self._RequestId
